package gui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.io.File;
import java.util.ArrayList;
import java.util.List;

import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.SwingConstants;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

public class NovaJanela extends JFrame {
	public NovaJanela() throws Exception {
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		setBounds(100, 100, 600, 450);

		// A montagem do leiaute deve vir antes do setVisible() para
		// que a janela se desenhe já com todos os componentes.
		init();
		setVisible(true);
	}

	/**
	 * Método que constrói todo o leiaute da janela.
	 * 
	 * @throws Exception
	 *           Caso ocorram erros, são propagados até o fim do programa.
	 */
	private void init() throws Exception {
		// Cria o rótulo que vai mostrar a foto, colocando-o no centro da janela.
		final JLabel rotuloImagem = new JLabel();
		add(rotuloImagem, BorderLayout.CENTER);

		// Monta um vetor com os nomes dos arquivos na pasta imagens.
		final File pastaImagens = new File(getClass().getResource("/imagens").toURI());
		List<String> listaImagens = new ArrayList<>();
		for (File arquivo : pastaImagens.listFiles())
			listaImagens.add(arquivo.getName());
		String[] vetorImagens = listaImagens.toArray(new String[] {});

		// Cria a caixa de combinação para selecionar a foto, colocando-a no rodapé.
		final JComboBox<String> caixaImagens = new JComboBox<>(vetorImagens);
		add(caixaImagens, BorderLayout.PAGE_END);
		caixaImagens.addItemListener(new ItemListener() {
			@Override
			public void itemStateChanged(ItemEvent e) {
				String nomeArquivo = caixaImagens.getSelectedItem().toString();
				String caminhoArquivo = "/imagens/" + nomeArquivo;
				Icon imagem = new ImageIcon(getClass().getResource(caminhoArquivo));
				rotuloImagem.setIcon(imagem);
			}
		});

		// Adiciona um botão que permite escolher um arquivo qualquer do disco.
		JButton botaoEscolher = new JButton("Escolher arquivo...");
		add(botaoEscolher, BorderLayout.PAGE_START);
		botaoEscolher.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				JFileChooser jfc = new JFileChooser(pastaImagens);
				int resultado = jfc.showOpenDialog(NovaJanela.this);
				if (resultado == JFileChooser.APPROVE_OPTION) {
					File arquivoEscolhido = jfc.getSelectedFile();
					Icon imagem = new ImageIcon(arquivoEscolhido.getAbsolutePath());
					rotuloImagem.setIcon(imagem);
				}
			}
		});

		// Adiciona uma lista de cores à esquerda e permite que o usuário as misture, 
		// formando a cor de fundo da tela (basta selecionar mais de uma).
		Color[] cores = new Color[] { Color.RED, Color.GREEN, Color.BLUE };
		final JList<Color> listaCores = new JList<>(cores);
		add(listaCores, BorderLayout.LINE_START);
		listaCores.addListSelectionListener(new ListSelectionListener() {
			@Override
			public void valueChanged(ListSelectionEvent e) {
				List<Color> coresSelecionadas = listaCores.getSelectedValuesList();
				int red = 0, green = 0, blue = 0;
				for (Color cor : coresSelecionadas) {
					red += cor.getRed();
					green += cor.getGreen();
					blue += cor.getBlue();
				}
				red /= coresSelecionadas.size();
				green /= coresSelecionadas.size();
				blue /= coresSelecionadas.size();
				Color novaCor = new Color(red, green, blue);
				getContentPane().setBackground(novaCor);
			}
		});
	}

	public static void main(String[] args) throws Exception {
		new NovaJanela();
	}
}
